@@ -119,7 +119,7 @@ class LinuxDevice(object):
     '''
     A base class for common linux devices.
     '''
-    release = '1.2.1'
+    release = '1.2.5'
 
     LOG_EMERG = 0   # not used
     LOG_ALERT = 1   # not used
@@ -500,7 +500,13 @@ class LinuxDevice(object):
         Sematics is like self.cli, see detail in self.cli()
         '''
         result = ""
+        cmdlist = []
         for cmd in args:
+            if isinstance(cmd, list):
+                cmdlist.extend(cmd)
+            else:
+                cmdlist.append(cmd)
+        for cmd in cmdlist:
             for c in StringIO(cmd.strip()).readlines():
                 if c.strip() and c.strip()[0] != '#':
                     result = self.__cmd(c.strip(), **kwargs)
